Queries the geoconnex.us reference feature server for available layers and attributes.

discover_geoconnex_reference()

Value

data.frame containing layers available and fields that are available to query.

Examples

# \donttest{
  discover_geoconnex_reference()
#> GET https://reference.geoconnex.us/
#> GET https://reference.geoconnex.us/collections
#> GET https://reference.geoconnex.us/collections/hu02/queryables?f=json
#> GET https://reference.geoconnex.us/collections/hu04/queryables?f=json
#> GET https://reference.geoconnex.us/collections/hu06/queryables?f=json
#> GET https://reference.geoconnex.us/collections/hu08/queryables?f=json
#> GET https://reference.geoconnex.us/collections/hu10/queryables?f=json
#> GET https://reference.geoconnex.us/collections/hu12/queryables?f=json
#> GET https://reference.geoconnex.us/collections/nat_aq/queryables?f=json
#> GET https://reference.geoconnex.us/collections/principal_aq/queryables?f=json
#> GET https://reference.geoconnex.us/collections/sec_hydrg_reg/queryables?f=json
#> GET https://reference.geoconnex.us/collections/gages/queryables?f=json
#> GET https://reference.geoconnex.us/collections/mainstems/queryables?f=json
#> GET https://reference.geoconnex.us/collections/mainstems_v3/queryables?f=json
#> GET https://reference.geoconnex.us/collections/dams/queryables?f=json
#> GET https://reference.geoconnex.us/collections/pws/queryables?f=json
#> GET https://reference.geoconnex.us/collections/states/queryables?f=json
#> GET https://reference.geoconnex.us/collections/counties/queryables?f=json
#> GET https://reference.geoconnex.us/collections/aiannh/queryables?f=json
#> GET https://reference.geoconnex.us/collections/cbsa/queryables?f=json
#> GET https://reference.geoconnex.us/collections/ua10/queryables?f=json
#> GET https://reference.geoconnex.us/collections/places/queryables?f=json
#> # A tibble: 258 × 6
#>    id    title description                                 url   attribute type 
#>    <chr> <chr> <chr>                                       <chr> <chr>     <chr>
#>  1 hu02  HU02  Two-digit Hydrologic Regions from USGS NHD… http… fid       inte…
#>  2 hu02  HU02  Two-digit Hydrologic Regions from USGS NHD… http… uri       stri…
#>  3 hu02  HU02  Two-digit Hydrologic Regions from USGS NHD… http… name      stri…
#>  4 hu02  HU02  Two-digit Hydrologic Regions from USGS NHD… http… gnis_url  stri…
#>  5 hu02  HU02  Two-digit Hydrologic Regions from USGS NHD… http… gnis_id   inte…
#>  6 hu02  HU02  Two-digit Hydrologic Regions from USGS NHD… http… huc2      stri…
#>  7 hu02  HU02  Two-digit Hydrologic Regions from USGS NHD… http… loaddate  stri…
#>  8 hu04  HU04  Four-digit Hydrologic Subregion from USGS … http… fid       inte…
#>  9 hu04  HU04  Four-digit Hydrologic Subregion from USGS … http… uri       stri…
#> 10 hu04  HU04  Four-digit Hydrologic Subregion from USGS … http… name      stri…
#> # ℹ 248 more rows
# }