| get_DM | R Documentation |
Traverse NHDPlus network downstream main stem
get_DM(network, comid, distance = NULL, sort = FALSE, include = TRUE)
network |
data.frame NHDPlus flowlines including at a minimum: COMID, LENGTHKM, DnHydroseq, and Hydroseq. |
comid |
integer identifier to start navigating from. |
distance |
numeric distance in km to limit how many COMIDs are returned. The COMID that exceeds the distance specified is returned. |
sort |
if TRUE, the returned COMID vector will be sorted in order of distance from the input COMID (nearest to farthest) |
include |
if TRUE, the input COMID will be included in the returned COMID vector |
integer vector of all COMIDs downstream of the starting COMID along the mainstem
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.