| get_UM | R Documentation |
Traverse NHDPlus network upstream main stem
get_UM(network, comid, distance = NULL, sort = FALSE, include = TRUE)
network |
data.frame NHDPlus flowlines including at a minimum: COMID,Pathlength, LevelPathI, and Hydroseq. |
comid |
integer identifier to start navigating from. |
distance |
numeric distance in km to limit how many COMIDs are |
sort |
if TRUE, the returned COMID vector will be sorted in order of distance from the input COMID (nearest to farthest) |
include |
if TRUE, the input COMID will be included in the returned COMID vector returned. The COMID that exceeds the distance specified is returned. |
integer vector of all COMIDs upstream of the starting COMID along the mainstem
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.