get_characteristics_metadata: Get catchment characteristics metadata table

View source: R/get_vaa.R

get_characteristics_metadataR Documentation

Get catchment characteristics metadata table

Description

Download and cache table of catchment characteristics.

When source = "usgs" (the default), returns metadata from: Wieczorek, M.E., Jackson, S.E., and Schwarz, G.E., 2018, Select Attributes for NHDPlus Version 2.1 Reach Catchments and Modified Network Routed Upstream Watersheds for the Conterminous United States (ver. 3.0, January 2021): U.S. Geological Survey data release, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5066/F7765D7V")}.

When source = "streamcat", returns metric metadata from the EPA StreamCat dataset accessed via the StreamCatTools package (must be installed separately).

Usage

get_characteristics_metadata(search, source = "usgs", cache = TRUE)

Arguments

search

character string of length 1 to free search the metadata table. If no search term is provided the entire table is returned.

source

character "usgs" (default) or "streamcat".

cache

logical should cached metadata be used?

Examples


get_characteristics_metadata()


nhdplusTools documentation built on May 26, 2026, 5:06 p.m.