get_nldi_index: Get NLDI Index

View source: R/get_nldi.R

get_nldi_indexR Documentation

Get NLDI Index

Description

uses the Network Linked Data Index to retrieve and estimated network location for the given point. If not within a grid cell of a flowline, will use a raindrop trace service to find the nearest downslope flowline location.

Usage

get_nldi_index(location)

Arguments

location

numeric WGS84 lon/lat pair (X, Y)


nhdplusTools documentation built on Sept. 2, 2026, 9:07 a.m.