| get_raindrop_trace | R Documentation |
Uses a raindrop trace web service to trace the nhdplus digital elevation model to the nearest downslope flowline.
get_raindrop_trace(point, direction = "down")
point |
sfc POINT including crs as created by:
|
direction |
character |
sf data.frame containing raindrop trace and requested portion of flowline.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.