get_vaa: NHDPlusV2 Attribute Subset

View source: R/get_vaa.R

get_vaaR Documentation

NHDPlusV2 Attribute Subset

Description

Return requested NHDPlusV2 Attributes.

Usage

get_vaa(
  atts = NULL,
  path = get_vaa_path(),
  download = TRUE,
  updated_network = FALSE
)

Arguments

atts

character The variable names you would like, always includes comid

path

character path where the file should be saved. Default is a persistent system data as retrieved by nhdplusTools_data_dir. Also see: get_vaa_path

download

logical if TRUE, the default, will download VAA table if not found at path.

updated_network

logical default FALSE. If TRUE, updated network attributes from E2NHD and National Water Model retrieved from \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5066/P976XCVT")}.

Details

The VAA data is a aggregate table of information from the NHDPlusV2 elevslope.dbf(s), PlusFlowlineVAA.dbf(s); and NHDFlowlines. All data originates from the EPA NHDPlus Homepage here. To see the location of cached data on your machine use get_vaa_path. To view aggregate data and documentation, see here

Value

data.frame containing requested VAA data


nhdplusTools documentation built on Sept. 2, 2026, 9:07 a.m.