View source: R/index_nhdplus.R
| get_waterbody_index | R Documentation |
given an sf point geometry column, return waterbody id, and COMID of dominant artificial path
get_waterbody_index(waterbodies, points, flines = NULL, search_radius = NULL)
waterbodies |
sf data.frame of type POLYGON or MULTIPOLYGON including COMID attributes. |
points |
sfc of type POINT |
flines |
sf data.frame of type LINESTRING or MULTILINESTRING including COMID, WBAREACOMI, and Hydroseq attributes |
search_radius |
units class with a numeric value indicating how far to search for a waterbody boundary in units of provided projection. Set units with set_units. |
data.frame with two columns, COMID, in_wb_COMID, near_wb_COMID, near_wb_dist, and outlet_fline_COMID. Distance is in units of provided projection.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.