get_xs_point: Get Cross Section From Point (experimental)

View source: R/get_oaproc.R

get_xs_pointR Documentation

Get Cross Section From Point (experimental)

Description

Uses a cross section retrieval web services to retrieve a cross section given a point and specified width. Orientation is determined based on direction of a the flowline found near point. This function uses a 10m National Elevation Dataset request on the back end.

Usage

get_xs_point(point, width, num_pts)

Arguments

point

sfc POINT including crs as created by: sf::st_sfc(sf::st_point(.. ,..), crs)crs.

width

Cross section width in meters.

num_pts

numeric number of points to retrieve along the cross section.

Value

sf data.frame containing points retrieved.


nhdplusTools documentation built on Sept. 2, 2026, 9:07 a.m.