get_xs_points: Get Cross Section Endpoints (experimental)

View source: R/get_oaproc.R

get_xs_pointsR Documentation

Get Cross Section Endpoints (experimental)

Description

Uses a cross section retrieval web services to retrieve a cross section between two endpoints.

Usage

get_xs_points(point1, point2, num_pts, res = 1)

Arguments

point1

sfc POINT including crs as created by: sf::st_sfc(sf::st_point(.. ,..), crs)

point2

sfc POINT including crs.

num_pts

numeric number of points to retrieve along the cross section.

res

integer resolution of 3D Elevation Program data to request. Must be on of: 1, 3, 5, 10, 30, 60.

Value

sf data.frame containing points retrieved.


nhdplusTools documentation built on Sept. 2, 2026, 9:07 a.m.