View source: R/get_nhdplushr.R
| make_standalone | R Documentation |
Cleans up and prepares NHDPlusHR regional data for use as complete NHDPlus data. The primary modification applied is to ensure that any flowpath that exits the domain is labeled as a terminal path and attributes are propagated upstream such that the domain is independently complete.
make_standalone(flowlines)
flowlines |
sf data.frame of NHDPlusHR flowlines. |
sf data.frame containing standalone network
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.