| navigate_network | R Documentation |
Provides a full feature network navigation function that will work with local or web service data. Parameter details provide context.
navigate_network(
start,
mode = "UM",
network = NULL,
output = "flowlines",
distance_km = 10,
trim_start = FALSE,
trim_stop = FALSE,
trim_tolerance = 5
)
start |
list, integer, sf, or sfc if list must be a valid NLDI feature if integer must be a valid comid. If sf, must contain a "comid" field. |
mode |
character chosen from c(UM, DM, UT, or DD) |
network |
sf should be compatible with network navigation functions If NULL, network will be derived from requests to the NLDI |
output |
character flowline or a valid NLDI data source |
distance_km |
numeric distance to navigate in km |
trim_start |
logical should start be trimmed or include entire catchment? |
trim_stop |
logical should stop(s) be trimmed or include entire catchment(s)? # Not supported |
trim_tolerance |
numeric from 0 to 100 percent of flowline length. If amount to trim is less than this tolerance, no trim will be applied. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.