Function to prep NHDPlus data for use by hydrogeofetch functions
prepare_nhdplus(
flines,
min_network_size = 0,
min_path_length = 0,
min_path_size = 0,
purge_non_dendritic = TRUE,
warn = TRUE,
error = TRUE,
skip_toCOMID = FALSE,
align_names = TRUE
)data.frame NHDPlus flowlines including: COMID, LENGTHKM, FTYPE (or FCODE), TerminalFl, FromNode, ToNode, TotDASqKM, StartFlag, StreamOrde, StreamCalc, TerminalPa, Pathlength, and Divergence variables.
numeric Minimum size (sqkm) of drainage network to include in output.
numeric Minimum length (km) of terminal level path of a network.
numeric Minimum size (sqkm) of outlet level path of a drainage basin. Drainage basins with an outlet drainage area smaller than this will be removed.
logical Should non dendritic paths be removed or not.
logical controls whether warning an status messages are printed
logical controls whether to return potentially invalid data with a warning rather than an error
logical if TRUE, toCOMID will not be added to output.
logical
data.frame with prepared NHDPlus network attributes.