| get_catchment_characteristics | R Documentation |
Downloads (subsets of) catchment characteristics from a cloud data store. See get_characteristics_metadata for available characteristics.
When source = "usgs" (the default), data is retrieved from:
Wieczorek, M.E., Jackson, S.E., and Schwarz, G.E., 2018, Select Attributes
for NHDPlus Version 2.1 Reach Catchments and Modified Network Routed Upstream
Watersheds for the Conterminous United States (ver. 3.0, January 2021): U.S.
Geological Survey data release, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5066/F7765D7V")}.
When source = "streamcat", data is retrieved from the EPA StreamCat
dataset via the StreamCatTools package (must be installed separately).
The aoi parameter controls the area of interest for StreamCat queries.
get_catchment_characteristics(
varname,
ids,
reference_fabric = "nhdplusv2",
source = "usgs",
aoi = "cat"
)
varname |
character vector of desired variables. If repeated varnames
are provided, they will be downloaded once but duplicated in the output.
For |
ids |
numeric vector of identifiers (comids) from the specified fabric |
reference_fabric |
(not used) will be used to allow future specification of alternate reference fabrics |
source |
character |
aoi |
character area of interest for StreamCat queries. One of
|
get_catchment_characteristics("CAT_BFI", c(5329343, 5329427))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.