| get_elev_along_path | R Documentation |
Uses a cross section retrieval web services to retrieve elevation along a path.
get_elev_along_path(points, num_pts, res = 1, status = TRUE)
points |
sf data.frame containing a point column. |
num_pts |
numeric number of points to retrieve along the cross section. |
res |
integer resolution of 3D Elevation Program data to request. Must be on of: 1, 3, 5, 10, 30, 60. |
status |
logical |
sf data.frame containing points retrieved. Names include "id", "distance_m", "elevation_m", "spatial_ref", "geometry", and ".group". .group tracks which input point each set of output points belongs to.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.