View source: R/get_geoconnex.R
| get_geoconnex_reference | R Documentation |
Queries the geoconnex reference feature server for features of interest.
get_geoconnex_reference(
AOI,
type = NULL,
t_srs = NULL,
buffer = 0.5,
status = TRUE
)
AOI |
bbox, sf polygon or point, or a URL that will return an sf object when passed to read_sf |
type |
character the feature type chosen from discover_geoconnex_reference |
t_srs |
character (PROJ string or EPSG code) or numeric (EPSG code). A user specified - target -Spatial Reference System (SRS/CRS) for returned objects. Will default to the CRS of the input AOI if provided, and to 4326 for ID requests. |
buffer |
numeric. The amount (in meters) to buffer a POINT AOI by for an extended search. Default = 0.5 |
status |
boolean print status or not |
sf data.frame containing requested reference features
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.