| get_nldi_index | R Documentation |
uses the Network Linked Data Index to retrieve and estimated network location for the given point. If not within a grid cell of a flowline, will use a raindrop trace service to find the nearest downslope flowline location.
get_nldi_index(location)
location |
numeric WGS84 lon/lat pair (X, Y) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.