| get_xs_point | R Documentation |
Uses a cross section retrieval web services to retrieve a cross section given a point and specified width. Orientation is determined based on direction of a the flowline found near point. This function uses a 10m National Elevation Dataset request on the back end.
get_xs_point(point, width, num_pts)
point |
sfc POINT including crs as created by:
|
width |
Cross section width in meters. |
num_pts |
numeric number of points to retrieve along the cross section. |
sf data.frame containing points retrieved.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.